//
//  MapDemoViewController.swift
//  StucoCoreLocationDemo
//
//  Created by Amolak Nagi on 11/30/15.
//  Copyright © 2015 Amolak Nagi. All rights reserved.
//

import UIKit
import CoreLocation
import MapKit

class MapDemoViewController: UIViewController, CLLocationManagerDelegate, MKMapViewDelegate
{
    //Constants for Map Region
    let regionRadius : CLLocationDistance = 1000
    
    @IBOutlet weak var map: MKMapView!
    var locationManager : CLLocationManager = CLLocationManager()
    var thePin : MKPointAnnotation = MKPointAnnotation()
    
    
    //Class Initializer
    override func viewDidLoad()
    {
        super.viewDidLoad()
        
        //Initalize the location manager here
        self.locationManager.desiredAccuracy = kCLLocationAccuracyBest
        self.locationManager.delegate = self
        self.locationManager.requestWhenInUseAuthorization()
        self.locationManager.startUpdatingLocation()
        
        //Initialize the delegate for the MKMapView here
        self.map.delegate = self
        self.map.showsUserLocation = true
        
    }

    //Helper method to zoom our map into a given CLLocation
    func centerMapOnLocation(location: CLLocation)
    {
        let coordinateRegion = MKCoordinateRegionMakeWithDistance(location.coordinate,
            regionRadius * 2.0, regionRadius * 2.0)
        self.map.setRegion(coordinateRegion, animated: true)
    }
    
    //Helper method to place a pin on the map
    func placePinAtLocation(location: CLLocation)
    {
        //If you don't remove the previous pin, it won't ever go away
        self.map.removeAnnotation(self.thePin)
        
        //Create a new pin and place it on the map
        var pin = MKPointAnnotation()
        pin.coordinate = location.coordinate
        pin.title = "This is a title"
        pin.subtitle = "This is a subtitle"
        self.map.addAnnotation(pin)
        
        //Mark this pin as the old one
        self.thePin = pin
    }

    //Delegate method to retrieve the current location with CLLocationManager
    func locationManager(manager: CLLocationManager, didUpdateLocations locations: [CLLocation])
    {
        let latestLocation = locations[locations.count - 1]
        
        //centerMapOnLocation(latestLocation)
        //placePinAtLocation(latestLocation)
        
    }
    
    //Delegate method to retrieve the current location with MKMapView
    func mapView(mapView: MKMapView, didUpdateUserLocation userLocation: MKUserLocation)
    {
        centerMapOnLocation(userLocation.location!)
    }

}
